@@ -3,6 +3,7 @@ from python_helper.api.src.domain import Constant as c
 from python_helper.api.src.service import StringHelper, LogHelper
 from python_helper.api.src.helper import ObjectHelperHelper
 
+
 GENERATOR_CLASS_NAME = 'generator'
 UNKNOWN_OBJECT_CLASS_NAME = c.UNKNOWN.lower()
 
@@ -24,6 +25,7 @@ COLLECTION_CLASSES = (
     set
 )
 
+
 def equals(
     expected,
     toAssert,
@@ -85,6 +87,7 @@ def equals(
         else :
              return True
 
+
 def sortIt(thing) :
     if isDictionary(thing) :
         sortedDictionary = {}
@@ -99,6 +102,7 @@ def sortIt(thing) :
     else :
         return thing
 
+
 def getSortedCollection(thing) :
     return thing if (
         isNotCollection(thing) or isEmpty(thing)
@@ -111,6 +115,7 @@ def getSortedCollection(thing) :
         )
     )
 
+
 def filterIgnoreKeyList(objectAsDictionary,ignoreKeyList):
     if isDictionary(objectAsDictionary) and isNotNone(ignoreKeyList) :
         filteredObjectAsDict = {}
@@ -123,74 +128,110 @@ def filterIgnoreKeyList(objectAsDictionary,ignoreKeyList):
         return filteredObjectAsDict
     return objectAsDictionary
 
+
 def isEmpty(thing) :
     return StringHelper.isBlank(thing) if isinstance(thing, str) else isNone(thing) or isEmptyCollection(thing)
 
+
 def isNotEmpty(thing) :
     return not isEmpty(thing)
 
+
 def isEmptyCollection(thing) :
     return isCollection(thing) and 0 == len(thing)
 
+
 def isNotEmptyCollection(thing) :
     return isCollection(thing) and 0 < len(thing)
 
+
 def isList(thing) :
     return isinstance(thing, list)
 
+
 def isNotList(thing) :
     return not isList(thing)
 
+
 def isSet(thing) :
     return isinstance(thing, set)
 
+
 def isNotSet(thing) :
     return not isSet(thing)
 
+
 def isTuple(thing) :
     return isinstance(thing, tuple)
 
+
 def isNotTuple(thing) :
     return not isTuple(thing)
 
+
 def isDictionary(thing) :
     return isinstance(thing, dict)
 
+
 def isNotDictionary(thing) :
     return not isDictionary(thing)
 
+
 def isDictionaryClass(thingClass) :
     return dict == thingClass
 
+
 def isNotDictionaryClass(thingClass) :
     return not isDictionaryClass(thingClass)
 
+
 def isNone(instance) :
     return instance is None
 
+
 def isNotNone(instance) :
     return not isNone(instance)
 
+
 def isNativeClass(instanceClass) :
     return isNotNone(instanceClass) and instanceClass in NATIVE_CLASSES
 
+
 def isNotNativeClass(instanceClass) :
     return not isNativeClass(instanceClass)
 
+
 def isNativeClassInstance(instance) :
     return isNotNone(instance) and isNativeClass(instance.__class__)
 
+
 def isNotNativeClassIsntance(instance) :
     return not isNativeClassInstance(instance)
 
+
 def isCollection(instance) :
     return isNotNone(instance) and True in {isinstance(instance, c) for c in COLLECTION_CLASSES}
 
+
 def isNotCollection(instance) :
     return not isCollection(instance)
 
+
 def isNeitherNoneNorBlank(thing) :
     return isNotNone(thing) and StringHelper.isNotBlank(str(thing))
 
+
 def isNoneOrBlank(thing) :
     return isNone(thing) or StringHelper.isBlank(str(thing))
+
+
+def deleteDictionaryEntry(entryKey, dictionary):
+    if entryKey in dictionary:
+        dictionary.pop(entryKey)
+
+
+def deleteCollectionEntry(entry, collection):
+    if isDictionary(collection):
+        deleteDictionaryEntry(entry, collection)
+    elif entry in collection:
+        collection.remove(entry)
